=========
Changelog
=========

1.0.0 (2024-11)
===============

This is a different pthelma from the old 0.14, which had been abandoned
in favor of a number of separate packages. However, maintaining all
these separate packages was too cumbersome and now we re-combine them
here.
